@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Spectroscopy
-Version : 1.4.0
+Version : 1.4.1
 Author  : Stefano Covino
-Date    : 22/08/2012
+Date    : 20/12/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -17,6 +17,7 @@ History : (17/11/2010) First named version.
         : (23/10/2011) Flux density conversion.
         : (27/10/2011) FWHM variation with airmass and wavelength
         : (22/08/2012) Atmospheric extinction curves
+        : (20/12/2012) New atmospheric extinction curves.
 """
 
 
@@ -84,8 +85,12 @@ ClassLymAlphaDumpConst  = (8*math.pi**2*ElectronCharge**2)/(3*ElectronMass*Speed
 
 
 # Atmospheric extinction curves
-CP  =   'Paranal'
-LP  =   'LaPalma'
-LS  =   'LaSilla'
+CP   =   'Paranal'
+CPa  =   'CerroPachon'
+LP   =   'LaPalma'
+LS   =   'LaSilla'
+MK   =   'MaunaKea'
 
-AtmExtCurves = {CP : 'Paranal.dat', LP : 'LaPalma.dat', LS : 'LaSilla.dat'}
+AtmExtCurves = {CP : 'Paranal.dat', CPa : 'CerroPachon.dat', LP : 'LaPalma.dat', LS : 'LaSilla.dat', MK : 'MaunaKea.dat'}
+
+#
