@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Statistics
-Version : 1.3.0
+Version : 1.3.1
 Author  : Stefano Covino
-Date    : 04/12/2012
+Date    : 04/03/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -17,11 +17,12 @@ History : (28/10/2010) First version.
         : (30/04/2011) ChiSqIncrement.
         : (19/02/2012) ScoreatPercentile.
         : (27/08/2012) Faster sigma clipping for frames.
+        : (04/03/2013) MAD.
 """
 
 
 
 __all__ = ['AsymmetricGaussianDistrib', 'AverIterSigmaClipp', 'AverSigmaClippFrame', 
            'AverSigmaClippFrameFast', 'ChSqIncrement', 'CoordDistanceMinimization', 'GenFitPars',
-           'GenGaussSet', 'ScoreatPercentile', 'WeightedMean', 'WeightedMeanFrame']
+           'GenGaussSet', 'MAD', 'ScoreatPercentile', 'WeightedMean', 'WeightedMeanFrame']
 
