@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.1.2
+Version : 1.1.8
 Author  : Stefano Covino
-Date    : 06/12/2012
+Date    : 20/03/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -81,6 +81,12 @@ History : (28/09/2010) First named version.
         : (27/09/2012) V. 3.10.7b3 and SRPTime.
         : (04/12/2012) V. 3.10.7b4.
         : (06/12/2012) V. 3.10.7.
+        : (13/12/2012) V. 3.10.8b1.
+        : (18/12/2012) V. 3.10.8b2.
+        : (20/12/2012) V. 3.10.8b3.
+        : (11/02/2013) V. 3.10.8b4.
+        : (18/03/2013) V. 3.10.8b5.
+        : (20/03/2013) V. 3.10.8b6 and V. 3.10.8
 """
 
 
@@ -95,5 +101,5 @@ __all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhot
 
 
 # Version
-__version__ = '3.10.7'
+__version__ = '3.10.8'
 
